package cn.com.infosec.crypto.macs;

import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.ExtendedDigest;
import cn.com.infosec.crypto.Mac;
import cn.com.infosec.crypto.params.KeyParameter;
import java.util.Hashtable;

public class HMac implements Mac {
   private static final byte IPAD = 54;
   private static final byte OPAD = 92;
   private static Hashtable blockLengths;
   private Digest digest;
   private int digestSize;
   private int blockLength;
   private byte[] inputPad;
   private byte[] outputPad;

   static {
      Hashtable var10000 = blockLengths = new Hashtable();
      Integer var0;
      var0 = new Integer.<init>(32);
      var10000.put("GOST3411", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(16);
      var10000.put("MD2", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("MD4", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("MD5", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("RIPEMD128", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("RIPEMD160", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("SHA-1", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("SHA-224", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("SHA-256", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(128);
      var10000.put("SHA-384", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(128);
      var10000.put("SHA-512", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("Tiger", var0);
      var10000 = blockLengths;
      var0 = new Integer.<init>(64);
      var10000.put("Whirlpool", var0);
   }

   private static int getByteLength(Digest digest) {
      if (digest instanceof ExtendedDigest) {
         return ((ExtendedDigest)digest).getByteLength();
      } else {
         Integer var1;
         if ((var1 = (Integer)blockLengths.get(digest.getAlgorithmName())) != null) {
            return var1;
         } else {
            throw new IllegalArgumentException("unknown digest passed: " + digest.getAlgorithmName());
         }
      }
   }

   public HMac(Digest digest) {
      this(digest, getByteLength(digest));
   }

   private HMac(Digest digest, int byteLength) {
      this.digest = digest;
      this.digestSize = digest.getDigestSize();
      this.blockLength = byteLength;
      this.inputPad = new byte[byteLength];
      this.outputPad = new byte[byteLength];
   }

   public String getAlgorithmName() {
      return this.digest.getAlgorithmName() + "/HMAC";
   }

   public Digest getUnderlyingDigest() {
      return this.digest;
   }

   public void init(CipherParameters params) {
      this.digest.reset();
      byte[] var10000;
      byte[] var10001;
      byte[] var2;
      byte[] params1;
      int params2;
      int var5;
      if ((params1 = ((KeyParameter)params).getKey()).length > this.blockLength) {
         this.digest.update(params1, 0, params1.length);
         this.digest.doFinal(this.inputPad, 0);

         for(params2 = this.digestSize; params2 < (var2 = this.inputPad).length; ++params2) {
            var2[params2] = 0;
         }
      } else {
         var10000 = params1;
         var10001 = params1;
         byte[] var10002 = params1;
         params1 = this.inputPad;
         var5 = var10002.length;
         System.arraycopy(var10001, 0, params1, 0, var5);

         for(params2 = var10000.length; params2 < (var2 = this.inputPad).length; ++params2) {
            var2[params2] = 0;
         }
      }

      var10000 = this.inputPad;
      this.outputPad = params1 = new byte[var10000.length];
      var5 = var10000.length;
      System.arraycopy(var10000, 0, params1, 0, var5);

      for(params2 = 0; params2 < (var2 = this.inputPad).length; ++params2) {
         var2[params2] = (byte)(var2[params2] ^ 54);
      }

      for(params2 = 0; params2 < (var2 = this.outputPad).length; ++params2) {
         var2[params2] = (byte)(var2[params2] ^ 92);
      }

      var10001 = this.inputPad;
      this.digest.update(var10001, 0, var10001.length);
   }

   public int getMacSize() {
      return this.digestSize;
   }

   public void update(byte in) {
      this.digest.update(in);
   }

   public void update(byte[] in, int inOff, int len) {
      this.digest.update(in, inOff, len);
   }

   public int doFinal(byte[] out, int outOff) {
      int var3;
      byte[] var4 = new byte[var3 = this.digestSize];
      this.digest.doFinal(var4, 0);
      byte[] var10003 = this.outputPad;
      this.digest.update(var10003, 0, var10003.length);
      this.digest.update(var4, 0, var3);
      int var10000 = this.digest.doFinal(out, outOff);
      this.reset();
      return var10000;
   }

   public void reset() {
      this.digest.reset();
      byte[] var10001 = this.inputPad;
      this.digest.update(var10001, 0, var10001.length);
   }
}
